@@ -58,6 +58,7 @@ public:
         Name,
         Category,
         OldName,
+        Description,
         Routes,
         Cuisine,
         Diet,
@@ -75,6 +76,7 @@ public:
         CapacityCharing,
         MaxStay,
         DiaperChangingTable,
+        Gender,
         Wikipedia,
         Address,
         Phone,
@@ -86,7 +88,10 @@ public:
         PaymentCreditCard,
         PaymentStoredValueCard,
         Wheelchair,
+        WheelchairLift,
         CentralKey,
+        SpeechOutput,
+        TactileWriting,
         OperatorName,
         Network,
         OperatorWikipedia,
@@ -140,6 +145,8 @@ private:
 
     template <typename KeyMapEntry, std::size_t N>
     void addEntryForKey(const char *keyName, const KeyMapEntry(&map)[N]);
+    template <typename KeyMapEntry, std::size_t N>
+    void addEntryForLocalizedKey(const char *keyName, const KeyMapEntry(&map)[N]);
 
     OSM::Element m_element;
 
